app.details.rots = {
    
    lat: null,
    lng: null,
        
    init: function() {
        this.lat = $.urlParam("lat");
        this.lng = $.urlParam("lng");
                
        this.initHighcharts();
        this.load();
    },
    
    load: function() {
        $.mobile.loading("show");
        $.getJSON(app.API_URL+'api/getDetailsRots/lat='+this.lat+'/lng='+this.lng, function(data) {
            app.details.rots.showGraph("#graphInorganic", "Anorganski elementi", data.inorganic.elements, data.inorganic.series);
            app.details.rots.showGraph("#graphOrganic", "Organske spojine", data.organic.elements, data.organic.series);
            app.details.rots.showCategories(data.categories);
            $.mobile.loading("hide");
        });
        
        app.map.getAddressFromCoords(this.lat, this.lng, function(address) {
            $("#address").html(address);
        });
    },
    
    initHighcharts: function() {
        var idCounter = 0;
            
        Highcharts.wrap(Highcharts.Renderer.prototype, 'color', function(proceed, color, elem, prop) {
            var markup;
            if (color && color.pattern && prop === 'fill') {
                // SVG renderer
                if (this.box.tagName == 'svg') {
                    var id = 'highcharts-pattern-'+ idCounter++;
                    var pattern = this.createElement('pattern')
                            .attr({
                                id: id,
                                patternUnits: 'userSpaceOnUse',
                                width: color.width,
                                height: color.height
                            })
                            .add(this.defs),
                        image = this.image(
                            color.pattern, 0, 0, color.width, color.height
                        )
                        .add(pattern);
                    return 'url(' + this.url + '#' + id + ')';
                
                // VML renderer
                } else {
                    
                    // Remove previous fills
                    if (elem.getElementsByTagName('fill').length) {
                        elem.removeChild(elem.getElementsByTagName('fill')[0]);                  
                    }
                     
                    // If colors are given, use those, else use the original colors
                    // of the pattern tile
                    if (color.color1 && color.color2) {
                        markup = ['<hcv:', prop, ' color="', color.color1, '" color2="', 
                                  color.color2, '" type="pattern" src="', color.pattern, '" />'].join('');
                    } else {
                        markup = this.prepVML(['<', prop, ' type="tile" src="', color.pattern, '" />']);
                    }
                    
                    elem.appendChild(
                        document.createElement(markup)
                    );   
                   
                    // Work around display bug on updating attached nodes
                    if (elem.parentNode.nodeType === 1) {
                        elem.outerHTML = elem.outerHTML
                    }
                }
                
            } else {
                return proceed.call(this, color, elem, prop);
            }
        });
    },
    
    showGraph: function(id, title, elements, series) {        
        $(id).highcharts({
            chart: {
                type: 'bar',
                backgroundColor: 'none'
            },
            title: {
                text: title
            },
            xAxis: {
                categories: elements
            },
            yAxis: {
                type: 'logarithmic',
                title: {
                    text: "mg/kg"
                }
            },
            legend: {
                enabled: false
            },
            tooltip: {
                headerFormat: '<span style="color:{point.color}; font-size: 12px">{series.name}</span><br/>',
                pointFormat: '<b>{point.value}</b><br/>',
                style: {
                    width: 300
                }
            },
            plotOptions: {
                series: {
                    stacking: 'normal',
                    borderWidth: 0
                }
            },
            credits: {
                enabled: false
            },
            series: series
        });  
    },
    
    showCategories: function(categories) {
        $("#graphLegend").empty();
        $.each(categories, function(key, category) {
            var c = $(
                        "<li>" +
                            "<span><small class='colorBox' style='background: "+category.color+"; repeat-y 0 0;'>&nbsp;</small>"+category.title+"</span>" +
                        "</li>"
                    );
            $("#graphLegend").append(c);
        });
    }
}