app.map = {

    map: {},
    zoom: 9,
    homeMarker: false,
    homeCoords: false,
    useGps: true,
    gpsRunning: false,
    gpsTimeout: 10000,
    focused: false,
    resizeCanvasInit: false,
    
    init: function() {
        
        if(!this.resizeCanvasInit) {
            this.resizeCanvasInit = true;
            $(window).bind('resize', function(event) {
                app.map.resizeCanvas();
            });
        }
        app.map.resizeCanvas();
        
        var mapOptions = {
            minZoom: 8,
            zoom: app.map.zoom,
            center: new google.maps.LatLng(46.06, 14.51),
            mapTypeId: google.maps.MapTypeId.ROADMAP,
            mapTypeControlOptions: {
                mapTypeIds: [google.maps.MapTypeId.ROADMAP, google.maps.MapTypeId.HYBRID]
            },
            disableDefaultUI: true,
            mapTypeControl: false,
            scaleControl: true,
            zoomControl: true,
            zoomControlOptions: {
                style: google.maps.ZoomControlStyle.SMALL 
            },
            optimized: false,
            styles: [
                {
                    featureType: "poi",
                    elementType: "labels",
                    stylers: [{ visibility: "off" }]
                }
            ]            
        };
        this.map = new google.maps.Map(document.getElementById("mapCanvas"), mapOptions);
                
        this.homeMarker = new google.maps.Marker({map: this.map, clickable: false, flat: true, optimized: false});
        this.homeMarker.setIcon('img/home.png');
            
        if(this.homeCoords) {
            this.homeMarker.setPosition(this.homeCoords);
            this.map.setCenter(this.homeCoords);
        }
                
        google.maps.event.addListener(this.map, 'zoom_changed', function() {
            app.map.zoom = app.map.map.getZoom();
        });
        
        google.maps.event.addListener(this.map, 'click', function(event) {
            app.map.useGps = false;
            var coords = event.latLng;
            app.map.setHome(coords.lat(), coords.lng());
        });
        
        this.initGps();
    },
    
    resizeCanvas: function() {
        var screenWidth = $(window).width();
        var screenHeight = $(window).height();
        
        $("#mapCanvas").width(screenWidth);
        $("#mapCanvas").height(screenHeight);
    },
    
    showDetails: function() {
        if(typeof(this.homeCoords) == 'undefined' || this.homeCoords == null) return;
        
        
        $.mobile.changePage("details_rots.html?lat="+this.homeCoords.lat()+"&lng="+this.homeCoords.lng());
    },
    
    setHomeFromAddress: function(address) {
        this.getCoordsFromAddress(address, function(coords) {
             app.map.setHome(coords.lat(), coords.lng(), true);
        });
    },
    
    setHomeFromGps: function() {
        if(!app.map.useGps) return;
        
        navigator.geolocation.getCurrentPosition(
            function(position) {
                if(app.map.useGps) {
                    app.map.setHome(position.coords.latitude, position.coords.longitude, !app.map.focused);
                    app.map.useGps = false;
                    app.map.focused = true;
                }
            },
            function(error) {
            },
            { maximumAge: 1000000, timeout: app.map.gpsTimeout, enableHighAccuracy: true }
        );
    },

    setHome: function(lat, lng, focus) {
        if(typeof(focus) == 'undefined') focus = false;
        var coords = new google.maps.LatLng(lat, lng);
        this.homeCoords = coords;
        this.homeMarker.setPosition(coords);
        
        if(focus) {
            this.map.panTo(coords, 14);
            this.map.setZoom(14);
        }
    },
    
    initGps: function() {
        if(this.gpsRunning) return;
        this.gpsRunning = true;
        
        var loop = function() {
            app.map.setHomeFromGps();
            setTimeout(
                function() {
                    loop();
                },
                app.map.gpsTimeout
            );
        };
        loop();
    },
    
    enableGps: function() {
        this.useGps = true;
        this.focused = false;
        this.setHomeFromGps();
    },
    
    getCoordsFromAddress: function(address, onSuccess) {           
        address = address.toLowerCase();
        address = address.replace("", "s");
        address = address.replace("", "c");
        address = address.replace("", "z");
        
        var geocoder = new google.maps.Geocoder();
        geocoder.geocode( {'address': address+', Slovenia', 'region': 'SL' }, function(results, status) {
            if(status == google.maps.GeocoderStatus.OK && results[0]) {
                onSuccess(results[0].geometry.location);
            }
        });
    },
    
    getAddressFromCoords: function(lat, lng, onSuccess) {    
        var coords = new google.maps.LatLng(lat, lng);
             
        var geocoder = new google.maps.Geocoder();
        geocoder.geocode( {'latLng': coords}, function(results, status) {
            if(status == google.maps.GeocoderStatus.OK && results[1]) {
                var address = results[0].formatted_address;
                address = address.replace(", Slovenija", "");
                address = address.replace(", Slovenia", "");
                onSuccess(address);
            }
        });
    }
    
}